@@ -59,12 +59,53 @@ class Service:
             "name": name,
             "filter": the_filter})
 
+class ContextInput(object):
+    def  __getitem__(self, item):
+        return self.context.getInputValue(item)
 
-class Context:
+    def __setitem__(self, key, value):
+        self.context.setInputValue(key,value)
+
+class ContextJsonValue(object):
+    def  __getitem__(self, item):
+        return self.context.getJsonValue(self.item,item)
+
+    def __setitem__(self, key, value):
+        self.context.setJsonValue(self.item,key,value)
+
+class ContextJson(object):
+    def __getattr__(self, item):
+        json_value= ContextJsonValue()
+        json_value.context=self.context
+        json_value.item=item
+        return json_value
+
+class Context(object):
     bpm: BPMService
+    input: ContextInput
+    json: ContextJson
 
     def __init__(self, bpm: BPMService):
-        self.bpm = bpm
+        super(Context,self).__setattr__('bpm', bpm)
+        super(Context, self).__setattr__('input', ContextInput())
+        super(Context, self).__setattr__('json', ContextJson())
+        self.input.context=self
+        self.json.context=self
+
+    def __setattr__(self, key, value):
+        if key in dir(self):
+            super(Context,self).__setattr__(key, value)
+        else:
+            self.setValue(key,value)
+
+    def __getattr__(self, item):
+        return self.getValue(item)
+
+    def  __getitem__(self, item):
+        return self.getValue(item)
+
+    def __setitem__(self, key, value):
+        return self.setValue(key,value)
 
     def setValue(self, variable: str, value: Any, address=None):
         self.bpm.exec(script="_____context_____.setAttribute('" + variable + "',_____variable_____,100)",
